@@ -64,6 +64,7 @@ typedef struct MenuRootStatic
 	unsigned short items;
 	FvwmPicture *sidePic;
 	Pixel sideColor;
+	unsigned int used_mini_icons;
 	/* Menu Face */
 	MenuStyle *ms;
 	/* permanent flags */
@@ -103,6 +104,7 @@ typedef struct MenuRootStatic
 #define MR_ITEMS(m)              ((m)->s->items)
 #define MR_SIDEPIC(m)            ((m)->s->sidePic)
 #define MR_SIDECOLOR(m)          ((m)->s->sideColor)
+#define MR_USED_MINI_ICONS(m)    ((m)->s->used_mini_icons)
 #define MR_STYLE(m)              ((m)->s->ms)
 /* flags */
 #define MR_FLAGS(m)              ((m)->s->flags)
@@ -167,11 +169,11 @@ typedef struct MenuRootDynamic
 	struct
 	{
 		Pixel *d_pixels;
-		int d_npixels;
+		unsigned int d_npixels;
 	} stored_pixels; /* alloc pixels when dithering is used for gradients */
 } MenuRootDynamic;
 
-/* access macros to static menu members */
+/* access macros to dynamic menu members */
 #define MR_ORIGINAL_MENU(m)         ((m)->d->original_menu)
 #define MR_NEXT_MENU(m)             ((m)->d->next_menu)
 #define MR_CONTINUATION_MENU(m)     ((m)->d->continuation_menu)
@@ -352,6 +354,6 @@ void SetMenuCursor(Cursor cursor);
 void repaint_transparent_menu(
 	MenuRepaintTransparentParameters *prtmp,
 	Bool first, int x, int y, int end_x, int end_y);
-void menu_expose(XEvent *event, FvwmWindow *fw);
+Bool menu_expose(XEvent *event, FvwmWindow *fw);
 int menu_binding(int button,KeySym keysym,int modifier,char *action);
 #endif /* _MENUS_ */
