@@ -85,7 +85,7 @@ typedef enum
 	PR_SCREEN_CURRENT = 0,
 	PR_SCREEN_STYLE,
 	PR_SCREEN_X_RESOURCE_FVWMSCREEN,
-	PR_SCREEN_IGNORE_CAPTURE,
+	PR_SCREEN_IGNORE_CAPTURE
 } preason_screen_t;
 
 typedef enum
