@@ -21,10 +21,10 @@
  * </description>
  */
 Bool PImageCreatePixmapFromArgbData(
-	Display *dpy, Window win, CARD32 *data, int start, int width,
-	int height, Pixmap pixmap, Pixmap mask, Pixmap alpha, int *have_alpha,
-	int *nalloc_pixels, Pixel **alloc_pixels, int *no_limit,
-	FvwmPictureAttributes fpa);
+	Display *dpy, Window win, CARD32 *data, int start, unsigned int width,
+	unsigned int height, Pixmap pixmap, Pixmap mask, Pixmap alpha,
+	int *have_alpha, unsigned int *nalloc_pixels, Pixel **alloc_pixels,
+	int *no_limit, FvwmPictureAttributes fpa);
 /*
  * <pubfunc>PImageLoadPixmapFromFile
  * <description>
@@ -33,8 +33,9 @@ Bool PImageCreatePixmapFromArgbData(
  */
 Bool PImageLoadPixmapFromFile(
 	Display *dpy, Window win, char *file, Pixmap *pixmap, Pixmap *mask,
-	Pixmap *alpha, int *width, int *height, int *depth, int *nalloc_pixels,
-	Pixel **alloc_pixels, int *no_limit, FvwmPictureAttributes fpa);
+	Pixmap *alpha, unsigned int *width, unsigned int *height, int *depth,
+	unsigned int *nalloc_pixels, Pixel **alloc_pixels, int *no_limit,
+	FvwmPictureAttributes fpa);
 
 /*
  * <pubfunc>PImageLoadPixmapFromFile
@@ -63,6 +64,7 @@ Bool PImageLoadCursorPixmapFromFile(
  */
 Bool PImageLoadPixmapFromXpmData(
 	Display *dpy, Window win, int color_limit, char **data,
-	Pixmap *pixmap, Pixmap *mask, int *width, int *height, int *depth);
+	Pixmap *pixmap, Pixmap *mask, unsigned int *width,
+	unsigned int *height, int *depth);
 
 #endif /* PICTURE_IMAGE_LOADER_H  */
