@@ -436,7 +436,8 @@ Bool GetBackPixmap(void)
 	Pixmap maskPixmap;
 	char *path = NULL;
 	Pixmap tmp_pixmap;
-	int w=0, h=0, icon_depth = 0;
+	unsigned int w=0, h=0;
+	int icon_depth = 0;
 	FvwmPictureAttributes fpa;
 
 	fpa.mask = FPAM_NO_ALLOC_PIXELS | FPAM_NO_ALPHA;
